@@ -1,31 +1,15 @@
 /*
-Copyright (C) 2001 - 2013 Evan Teran
-                          evan.teran@gmail.com
+    SPDX-FileCopyrightText: 2001-2013 Evan Teran <evan.teran@gmail.com>
+    SPDX-FileCopyrightText: 2003-2005 Klaus Niederkrueger <kniederk@math.uni-koeln.de>
+    SPDX-FileCopyrightText: 1996-2000 Bernd Johannes Wuebben <wuebben@kde.org>
+    SPDX-FileCopyrightText: 1995 Martin Bartlett
 
-Copyright (C) 2003 - 2005 Klaus Niederkrueger
-                          kniederk@math.uni-koeln.de
-
-Copyright (C) 1996 - 2000 Bernd Johannes Wuebben
-                          wuebben@kde.org
-
-Copyright (C) 1995        Martin Bartlett
-
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation; either version 2 of
-the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "kcalc_core.h"
 #include "kcalc_settings.h"
+#include "kcalchistory.h"
 
 #include <QDebug>
 
