@@ -1,30 +1,15 @@
 /*
-Copyright (C) 2001 - 2013 Evan Teran
-                          evan.teran@gmail.com
+    SPDX-FileCopyrightText: 2001-2013 Evan Teran <evan.teran@gmail.com>
+    SPDX-FileCopyrightText: 1996-2000 Bernd Johannes Wuebben <wuebben@kde.org>
 
-Copyright (C) 1996 - 2000 Bernd Johannes Wuebben
-                          wuebben@kde.org
-
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation; either version 2 of 
-the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef KCALCDISPLAY_H_
-#define KCALCDISPLAY_H_
+#pragma once
 
+#include "knumber.h"
 #include <QFrame>
 #include <QVector>
-#include "knumber.h"
 
 class CalcEngine;
 class QTimer;
@@ -48,16 +33,11 @@ class QStyleOptionFrame;
   TODO: Check overflows, number of digits and such...
 */
 
-enum NumBase {
-    NB_BINARY  = 2,
-    NB_OCTAL   = 8,
-    NB_DECIMAL = 10,
-    NB_HEX     = 16
-};
+enum NumBase { NB_BINARY = 2, NB_OCTAL = 8, NB_DECIMAL = 10, NB_HEX = 16 };
 
-
-class KCalcDisplay : public QFrame {
-	Q_OBJECT
+class KCalcDisplay : public QFrame
+{
+    Q_OBJECT
 
 public:
     explicit KCalcDisplay(QWidget *parent = nullptr);
@@ -94,8 +74,7 @@ public:
 
     void changeSettings();
     void enterDigit(int data);
-    void updateFromCore(const CalcEngine &core,
-                        bool store_result_in_history = false);
+    void updateFromCore(const CalcEngine &core, bool store_result_in_history = false);
 
 public Q_SLOTS:
     void slotCut();
@@ -108,7 +87,7 @@ Q_SIGNALS:
     void changedAmount(const KNumber &);
 
 protected:
-    void  mousePressEvent(QMouseEvent *) override;
+    void mousePressEvent(QMouseEvent *) override;
     void paintEvent(QPaintEvent *p) override;
 
 private:
@@ -127,10 +106,10 @@ private:
     bool beep_;
     bool groupdigits_;
     bool twoscomplement_;
-    int  binaryGrouping_;
-    int  octalGrouping_;
-    int  hexadecimalGrouping_;
-    int  button_;
+    int binaryGrouping_;
+    int octalGrouping_;
+    int hexadecimalGrouping_;
+    int button_;
     bool lit_;
     NumBase num_base_;
 
@@ -150,7 +129,6 @@ private:
     QString str_int_exp_;
     QString str_status_[NUM_STATUS_TEXT];
 
-    QTimer* selection_timer_;
+    QTimer *const selection_timer_;
 };
 
-#endif
