@@ -1,22 +1,8 @@
 /*
-Copyright (C) 2001 - 2013 Evan Teran
-                          evan.teran@gmail.com
+    SPDX-FileCopyrightText: 2001-2013 Evan Teran <evan.teran@gmail.com>
+    SPDX-FileCopyrightText: 1996-2000 Bernd Johannes Wuebben <wuebben@kde.org>
 
-Copyright (C) 1996 - 2000 Bernd Johannes Wuebben
-                          wuebben@kde.org
-
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation; either version 2 of
-the License, or (at your option) any later version.
-
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
-
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "stats.h"
@@ -73,7 +59,7 @@ void KStats::clearLast()
 KNumber KStats::sum() const
 {
     KNumber result = KNumber::Zero;
-    for (const KNumber &x : qAsConst(data_)) {
+    for (const KNumber &x : std::as_const(data_)) {
         result += x;
     }
 
@@ -124,7 +110,7 @@ KNumber KStats::std_kernel()
     const KNumber mean_value = mean();
 
     if (mean_value.type() != KNumber::TYPE_ERROR) {
-        for (const KNumber &x : qAsConst(data_)) {
+        for (const KNumber &x : std::as_const(data_)) {
             result += (x - mean_value) * (x - mean_value);
         }
     }
@@ -140,7 +126,7 @@ KNumber KStats::sum_of_squares() const
 {
     KNumber result = KNumber::Zero;
 
-    for (const KNumber &x : qAsConst(data_)) {
+    for (const KNumber &x : std::as_const(data_)) {
         result += (x * x);
     }
 
